# Importing the data
bars <- read.csv("https://docs.google.com/spreadsheets/d/15TJZhuh7jKoO9fDr8LIcBr8T3vf_sUJudBD9L5o0rDM/pub?output=csv", stringsAsFactors=F)

# Loading knitr for markdown friendly tables
library(knitr)

kable(head(bars,10))

library(dplyr)

# How many incidents by Restaurant?
restaurants <- bars %>%
  group_by(Restaurant.name) %>%
  summarize(Total.Incidents=n()) %>%
  arrange(desc(Total.Incidents))

kable(head(restaurants,10))

# Installing rrefine
# You'll need to install Open Refine first

# install.packages("devtools")
devtools::install_github("vpnagraj/rrefine")

library(rrefine)

# You'll write the CSV to your computer
write.csv(bars, file = "data/bars.csv", row.names = FALSE)

# And then upload that file to the OpenRefine program
refine_upload(file = "data/bars.csv", project.name = "bars_cleanup", open.browser = TRUE)

# Done cleaning up the data?

# This function brings the Open Refine project back into R
bars_clean <- refine_export(project.name = "bars_cleanup2")

# Checking the number of unique Restaurant names
length(unique(bars_clean$Restaurant.name))

# Look at the first 6 rows
head(bars_clean)

# Cleaning up the zip code of any non numbers
bars_clean$zip <- gsub("[[:alpha:]]", "", bars_clean$citstzip)

# Did that work?
head(bars_clean$zip)

# Getting rid of some specific special characters
bars_clean$zip <- gsub(",", "", bars_clean$zip)
bars_clean$zip <- gsub(" ", "", bars_clean$zip)
bars_clean$zip <- gsub(".", "", bars_clean$zip, fixed=TRUE)
bars_clean$zip <- gsub("*", "", bars_clean$zip, fixed=TRUE)
bars_clean$zip <- gsub("/", "", bars_clean$zip, fixed=TRUE)

# How's that look?
head(bars_clean$zip)

# Creating a new column for state

# Using ifelse() to populate it based on some patterns

bars_clean$state <- ""
bars_clean$state <- ifelse(grepl(" RI", bars_clean$citstzip,  ignore.case = TRUE), "Rhode Island", bars_clean$state)

bars_clean$state <- ifelse(grepl(" MA", bars_clean$citstzip,  ignore.case = TRUE), "Massachusetts", bars_clean$state)
bars_clean$state <- ifelse(grepl("M.A.", bars_clean$citstzip,  ignore.case = TRUE), "Massachusetts", bars_clean$state)

bars_clean$state <- ifelse(grepl(",MA", bars_clean$citstzip,  ignore.case = TRUE), "Massachusetts", bars_clean$state)
bars_clean$state <- ifelse(grepl("MA.", bars_clean$citstzip,  ignore.case = TRUE), "Massachusetts", bars_clean$state)
bars_clean$state <- ifelse(grepl(" NH", bars_clean$citstzip,  ignore.case = TRUE), "New Hampshire", bars_clean$state)
bars_clean$state <- ifelse(grepl("N.H.", bars_clean$citstzip,  ignore.case = TRUE), "New Hampshire", bars_clean$state)

bars_clean$state <- ifelse(grepl("New Hampshire", bars_clean$citstzip,  ignore.case = TRUE), "New Hampshire", bars_clean$state)
bars_clean$state <- ifelse(grepl(" N H", bars_clean$citstzip,  ignore.case = TRUE), "New Hampshire", bars_clean$state)

bars_clean$state <- ifelse(grepl(" CT", bars_clean$citstzip,  ignore.case = TRUE), "Connecticut", bars_clean$state)
bars_clean$state <- ifelse(grepl("Rhode Island", bars_clean$citstzip,  ignore.case = TRUE), "Rhode Island", bars_clean$state)

bars_clean$state <- ifelse(grepl(" VT", bars_clean$citstzip,  ignore.case = TRUE), "Vermont", bars_clean$state)

# Cleaning up some town names based on abbreviations
bars_clean$town <- gsub(",.*", "", bars_clean$citstzip)
bars_clean$town <- gsub(" MA.*", "", bars_clean$town, ignore.case=T)
bars_clean$town <- gsub("S.", "South ", bars_clean$town, fixed=TRUE)
bars_clean$town <- gsub("N.", "North ", bars_clean$town, fixed=TRUE)
bars_clean$town <- gsub("W.", "West  ", bars_clean$town, fixed=TRUE)
bars_clean$town <- gsub("E.", "North ", bars_clean$town, fixed=TRUE)

# Using the package stringr
library(stringr)

# Normalizing the cases in the text
bars_clean$town <- str_to_title(bars_clean$town)

# Let's look at the first 10 rows of the 3 specific location columns
head(bars_clean[c("zip", "state", "town")],10)
